@@ -9,6 +9,7 @@ from configparser import RawConfigParser
 from enum import Enum
 import boto3
 from botocore.exceptions import ClientError
+from subprocess import call
 
 
 class AwsPartition(Enum):
@@ -44,6 +45,14 @@ class AwsAuth():
             self.profile = parser.get(okta_profile, 'profile')
             self.logger.debug("Setting AWS profile to %s" % self.profile)
 
+    def set_default_profile(self, parser: RawConfigParser):
+        if not parser.has_section('default'):
+            parser.add_section('default')
+        for key, value in parser.items(self.profile):
+            parser.set('default', key, value)
+        self.logger.info("Setting default profile.")
+        with open(self.creds_file, 'w+') as configfile:
+            parser.write(configfile)
 
     def choose_aws_role(self, assertion, refresh_role):
         """ Choose AWS role from SAML assertion """
@@ -98,7 +107,7 @@ of roles assigned to you.""" % self.role)
         credentials = response['Credentials']
         return credentials
 
-    def check_sts_token(self, profile):
+    def check_sts_token(self):
         """ Verifies that STS credentials are valid """
         # Don't check for creds if profile is blank
         if not self.profile:
@@ -121,9 +130,9 @@ of roles assigned to you.""" % self.role)
 
         self.logger.debug("Checking STS token against ARN partition: %s" % self.aws_partition)
         if self.aws_partition == AwsPartition.AWS_US_GOV:
-            session = boto3.Session(profile_name=profile, region_name='us-gov-west-1')
+            session = boto3.Session(profile_name=self.profile, region_name='us-gov-west-1')
         else:
-            session = boto3.Session(profile_name=profile)
+            session = boto3.Session(profile_name=self.profile)
 
         sts = session.client('sts')
         try:
@@ -141,6 +150,8 @@ of roles assigned to you.""" % self.role)
             return False
 
         self.logger.info("STS credentials are valid. Nothing to do.")
+        AwsAuth.set_default_profile(self, parser)
+
         return True
 
     def write_sts_token(self, access_key_id, secret_access_key, session_token):
@@ -163,6 +174,9 @@ of roles assigned to you.""" % self.role)
             config.write(configfile)
         self.logger.info("Temporary credentials written to profile: %s" % self.profile)
         self.logger.info("Invoke using: aws --profile %s <service> <command>" % self.profile)
+        
+        if self.profile != 'default':
+            AwsAuth.set_default_profile(self, config)
 
     @staticmethod
     def __extract_available_roles_from(assertion):
@@ -225,3 +239,8 @@ of roles assigned to you.""" % self.role)
     def __find_predefined_role_from(self, roles):
         found_roles = filter(lambda role_tuple: role_tuple.role_arn == self.role, roles)
         return next(iter(found_roles), None)
+
+    def execute_aws_args(self, awscli_args, logger):
+        cmdline = ['aws', '--profile', self.profile] + list(awscli_args)
+        logger.info('Invoking: %s', ' '.join(cmdline))
+        call(cmdline)
